import functools
import logging

from loguru import logger
from config import LOGGER_INTERCEPT_STD_LOGGING
from flask import flash

# todo: the following handler does NOT catch print statements (currently used inside scan2report)


# https://loguru.readthedocs.io/en/stable/overview.html#entirely-compatible-with-standard-logging
class InterceptHandler(logging.Handler):
    def emit(self, record):
        # Get corresponding Loguru level if it exists
        try:
            level = logger.level(record.levelname).name
        except ValueError:
            level = record.levelno

        # Find caller from where originated the logged message
        frame, depth = logging.currentframe(), 2
        while frame.f_code.co_filename == logging.__file__:
            frame = frame.f_back
            depth += 1

        logger.opt(depth=depth, exception=record.exc_info).log(level, record.getMessage())


class FlashLog(object):
    @classmethod
    def info(cls, msg: str):
        cls.log_with_level(msg, "info")

    @classmethod
    def warning(cls, msg: str):
        cls.log_with_level(msg, "warning")

    @classmethod
    def error(cls, msg: str):
        cls.log_with_level(msg, "error")

    @staticmethod
    def log_with_level(msg: str, level: str = "info", depth: int = 2):
        loguru_to_flask = {'info': 'info', 'warning': 'warning', 'error': 'danger'}
        flask_flash_level = loguru_to_flask.get(level, "warning")
        loguru_level = level.upper()

        flash(msg, flask_flash_level)
        logger.opt(depth=depth).log(loguru_level, msg)


if LOGGER_INTERCEPT_STD_LOGGING:
    logging.basicConfig(handlers=[InterceptHandler()], level=0)

